# tanchan.components

Commands, message components and modals implemented by Tan-chan for use with Tanjun and Yuyo.

::: tanchan.components.buttons
    options:
        show_root_heading: true

::: tanchan.components.config
    options:
        show_root_heading: true

::: tanchan.components.eval
    options:
        show_root_heading: true

::: tanchan.components.help
    options:
        show_root_heading: true
